==> haskell-sandi-0.5-219-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-7GepThBkU2NIYgaFh0axtW
key:                  sandi-0.5-7GepThBkU2NIYgaFh0axtW
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  53872f154ebb88795d4694110af64a17
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-8.10.4/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/sandi-0.5
hs-libraries:         HSsandi-0.5-7GepThBkU2NIYgaFh0axtW
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    conduit-1.3.4.1-L6Bk3TSuZkDDhpI3wXn9O2 exceptions-0.10.4

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.5-220-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-GoLIe5WgRi12Sz4hKY46QW
key:                  sandi-0.5-GoLIe5WgRi12Sz4hKY46QW
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  ec2173acfe605d36938e5866e06c2f96
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-8.10.4/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/sandi-0.5
hs-libraries:         HSsandi-0.5-GoLIe5WgRi12Sz4hKY46QW
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    conduit-1.3.4.1-D7tjG3uoOloKYIrANBNmms exceptions-0.10.4

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
